#
# spec file for package swag
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           swag
Version:        1.16.4
Release:        1.4
Summary:        Automatically generate RESTful API documentation with Swagger 2.0 for Go
License:        MIT
URL:            https://github.com/swaggo/swag
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.22

%description
Swag converts Go annotations to Swagger Documentation 2.0. We've created a
variety of plugins for popular Go web frameworks. This allows you to quickly
integrate with an existing Go project (using Swagger UI).

%prep
%autosetup -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build ./cmd/%{name}

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license license
%{_bindir}/%{name}

%changelog
* Fri Oct 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.16.4:
  * new release (#1901)
  * chore: Update ci.yml (#1902)
  * Feat: Add support for parenthesis in router patterns (#1859)
  * fix: failing assert in enums test on 32bit (#1634)
  * Flags to parse internal and dependency package (#1894)
  * fix：parse all field names declared in a row (#1872)
  * Update docs for request and response headers (#1825)
  * update README (#1856)
  * support markdown description for declaration (#1893)
  * Fix param comment escaping issue (#1890)
  * Fix generics used with function scoped types (#1883)
  * fix parse nested structs and aliases (#1866)
  * adds support for pointer function scoped fields (#1841)
  * Fix global overrides for any/interface ref types (#1835)
  * Fixes Issue 1829 (#1830)
  * [Issue 1812] fix misalignment in expected.json and api.go
    messing with parser_test (#1836)
  * adds support for complex types with function scope (#1813)
  * Added suport for parsing comments inside of function bodies
    (#1824)
  * feat: read from stdin, write to stdout (#1831) (#1832)
  * fix issue: #1780: filter $GOROOT path (#1827)
  * chore(deps): bump google.golang.org/protobuf in /example/celler
    (#1775)
  * chore(deps): bump google.golang.org/protobuf (#1774)
  * chore(deps): bump google.golang.org/protobuf (#1773)
  * Feat: multi-arch docker image (#1756)
  * Added multiline support for @description attribute for
    securityDefinitions (#1786)
  * Handle case of empty GOROOT (#1798)
  * chore(deps): bump golang.org/x/net in
    /example/object-map-example (#1796)
  * chore(deps): bump golang.org/x/net in
    /example/go-module-support (#1795)
  * chore(deps): bump golang.org/x/net in /example/celler (#1794)
  * chore(deps): bump golang.org/x/net in /example/markdown (#1792)
  * chore(deps): bump golang.org/x/net from 0.17.0 to 0.23.0
    (#1793)
  * bump go version (#1797)
  * chore: fix some typos in comments (#1788)
  * add support for "title" tag (#1762)
  * Update docker go build version to 1.21 (#1758)
  * fix: remove dropped tags from general infos (#1764)
  * Update operation.go (#1753)
* Fri Sep 27 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Re-enable binary stripping and debuginfo boo#1210938
  * Use BuildRequires: golang(API) >= 1.22 rather than pin go1.22.
    The golang(API) expression allows use of newer go versions and
    integrates with the go metapackage via OBS prjconf Prefer:
  * Drop autosetup -p 1 arg only needed when package has patches
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
  * Drop go build -o arg, default binary name is package of main()
* Sat Jun 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package swag: Automatically generate RESTful API
  documentation with Swagger 2.0 for Go
